@@ -107,13 +107,13 @@ sub Mail
 
 
 #==============================================================================
-sub RegisterCleanup;
-#{
-#  my ($s, $sub) = @_;
-#  
-#  # This is too tightly-coupled:
-#  $s->context->r->pool->cleanup_register( $sub );
-#}# end RegisterCleanup()
+sub RegisterCleanup
+{
+  my ($s, $sub, @args) = @_;
+  
+  # This works both in "testing" mode and within a live mod_perl environment.
+  $s->context->r->pool->cleanup_register( $sub, \@args );
+}# end RegisterCleanup()
 
 
 #==============================================================================
